sdv.lite.tabular.TabularPreset.sample\_remaining\_columns
=========================================================

.. currentmodule:: sdv.lite.tabular

.. automethod:: TabularPreset.sample_remaining_columns